# Governance

Decentralized protocols need governance systems that can make decisions about protocol evolution, moderation, design, and other topics. The purpose of this document is to review how existing projects govern themselves. As all the protocols and applications covered are open source, we will look into general open source governance as well.

### ActivityPub

ActivityPub was developed by the Social Web Working Group (SWWG), which ran 2014-2018, and culminated in the recommendation of a set of social protocols including ActivityPub. It has reached W3C recommendation status, and is currently stewarded by the W3C.

### Matrix

Matrix was [initially developed within Amdocs](<https://en.wikipedia.org/wiki/Matrix_(protocol)>) by developers building a chat tool. Amdocs funded development from 2014-2017. In 2017, the core developers started a company, [New Vector](https://vector.im/), which now drives development. The Matrix protocol and specification is stewarded by the [Matrix.org Foundation](https://matrix.org/media/2019-06-10%20-%20Matrix.org%20Foundation%20CIC%20Rules.pdf). There is an annual vote of confidence in the project lead.

### XMPP

XMPP was developed by the open source Jabber community without funding. XMPP remains non-profit. The IETF created a XMPP working group in 2001 and eventually published [RFC 3920](https://datatracker.ietf.org/doc/rfc3920/) and [RFC 3921](https://datatracker.ietf.org/doc/rfc3921/). In 2007, the Jabber Software Foundation renamed to [XSF](https://xmpp.org/about/xmpp-standards-foundation.html) (XMPP Standards Foundation) with the focus of developing open protocol extensions to the IETF’s base XMPP specifications. It has several sponsors, a Board of Directors which oversees the business affairs of the organization, and a council that approves XMPP Extension Protocols. The council is elected by members of the XSF. These members define and implement XMPP extensions for new features. XSF jointly works with IETF to create more RFCs and extend the protocol.

The organizations sponsoring XSF are [ProcessOne](https://xmpp.org/sponsors/processone), [Tigase](https://xmpp.org/sponsors/tigase) and [USSHC](https://xmpp.org/sponsors/us-secure-hosting-center).

### IPFS

IPFS was built by the company [Protocol Labs](https://protocol.ai/), and continues to be stewarded by it in conjunction with an open source community. The core implementations working group, consisting of both employees of the company and external contributors, has decision-making authority over contributions to the IPFS protocol. Libp2p, IPLD, and Filecoin are stewarded by separate working groups.

### Ssb

The SSB community has created an [Open Collective Consortium](https://opencollective.com/secure-scuttlebutt-consortium) that manages donations. It creates an annual budget and allocates funds for bounties, or to a project approved by a monthly rotating ‘adjudicator’. [Sunrise-Choir](https://github.com/sunrise-choir) is a non-profit company run on donations, which aims to make SSB developer-friendly. The team members are core-contributors to SSB.

## Blockchain governance

Most blockchain protocols, like other open source projects, operate through rough consensus, guided by companies and foundations that direct resources towards development. Bitcoin has a [lead maintainer](https://blog.lopp.net/who-controls-bitcoin-core-/), who has oversight over all aspects of the project and coordinates releases. The role has been voluntarily passed along through the years. Companies such as [Chaincode Labs](https://chaincode.com/) and [Square Crypto](https://medium.com/@squarecrypto/what-were-building-lightning-development-kit-1ed58b0cab06) contribute to funding protocol development. The [Blockchain Governance Initiative Network](https://bgin-global.org/) recently formed for collaboration on issues. 

A few projects have experimented with on-chain governance, in which funding and decision-making is executed in a decentralized manner linked to the blockchain itself. Dash allows masternodes to cast votes for how to [allocate a "treasury"](https://www.dash.org/2017/09/07/dashdecentral/), consisting of ten percent of the block awards, to pay for projects that benefit Dash. Decred has a similar treasury allocation process, and uses a [blockchain-anchored proposal system](https://decred.org/adaptability/) to submit and vote on proposals. [DeepDAO](http://deepdao.io/) provides an updated listing of tokenized DAOs.

## Open Source Governance Links and Resources

- [How the Node.js Foundation Utilizes Participatory Governance to Build Its Community](https://thenewstack.io/node-js-foundation-utilizing-participatory-governance-models/)
- [Debian Constitution](https://www.debian.org/devel/constitution)
- [Roads and Bridges](https://www.fordfoundation.org/work/learning/research-reports/roads-and-bridges-the-unseen-labor-behind-our-digital-infrastructure/)
- [Governance without Foundations](https://nadiaeghbal.com/foundations)
- [Apache Foundation Governance](https://www.apache.org/foundation/governance/)
- [Wikipedia original statement of principles](https://en.wikipedia.org/w/index.php?oldid=409315229)
- [Gitcoin](https://gitcoin.co/) - bounties for git issues, and grants for ecosystem projects
